==> qtjambi-multimedia-debuginfo-linux-x64-6.6.0.jar: sources/QtJambiMultimedia/QScreenCapture_shell.h <==
#ifndef QSCREENCAPTURE_SHELL_H
#define QSCREENCAPTURE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtMultimedia/qscreencapture.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qvariant.h>
#include <QtGui/qscreen.h>
#include <QtMultimedia/qmediacapturesession.h>
#include <QtJambi/RegistryAPI>


class QScreenCapture_shell : public QScreenCapture, public QtJambiShellInterface
{
public:
    QScreenCapture_shell(QObject* parent0 = nullptr);
    ~QScreenCapture_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QScreenCapture_access : public QScreenCapture
{
};

#endif // QSCREENCAPTURE_SHELL_H

==> qtjambi-multimedia-debuginfo-linux-x64-6.7.1.jar: sources/QtJambiMultimedia/QScreenCapture_shell.h <==
#ifndef QSCREENCAPTURE_SHELL_H
#define QSCREENCAPTURE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtMultimedia/qscreencapture.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qvariant.h>
#include <QtGui/qscreen.h>
#include <QtMultimedia/qmediacapturesession.h>
#include <QtJambi/RegistryAPI>


class QScreenCapture_shell : public QScreenCapture, public QtJambiShellInterface
{
public:
    QScreenCapture_shell(QObject* parent0 = nullptr);
    ~QScreenCapture_shell() override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    friend class QScreenCapture_mshell;
    friend class QScreenCapture_oshell;
};


class QScreenCapture_mshell : public QScreenCapture_shell
{
public:
    using QScreenCapture_shell::QScreenCapture_shell;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
};


class QScreenCapture_oshell : public QScreenCapture_mshell
{
public:
    using QScreenCapture_mshell::QScreenCapture_mshell;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
private:
    jmethodID __shell_javaMethod(int pos) const;
};

struct QScreenCapture_access : public QScreenCapture
{
};

#endif // QSCREENCAPTURE_SHELL_H
